<?php
if ( ! defined( 'ABSPATH' ) ) exit;
class Event_Registration_Pro {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Event_Registration_Pro_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $Event_Registration_Pro    The string used to uniquely identify this plugin.
	 */
	protected $Event_Registration_Pro;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the Dashboard and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'event-registration-pro';
		$this->version = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks(); 
		$this->remove_left_menus(); 		
		$this->define_metaboxes(); 
	}
	
	

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Event_Registration_Pro_Loader. Orchestrates the hooks of the plugin.
	 * - Event_Registration_Pro_i18n. Defines internationalization functionality.
	 * - Event_Registration_Pro_Admin. Defines all hooks for the dashboard.
	 * - Event_Registration_Pro_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {


		/**
		 * utils.php
		 *
		 * util.php is a collection of useful functions and snippets that you need or could use every day, designed to avoid conflicts with existing projects.
		 *
		 */
		if ( ! class_exists( 'utilphp\util' ) ) {
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/util.php';
		}
		
		/**Font awesome css*/
		wp_enqueue_style( 'font-awesome', plugin_dir_url( __FILE__ ) . 'css/font-awesome.min.css', array(), $this->version, 'all' );
		
	
		/**
		 * WordPress Settings Framework
		 *
		 * The WordPress Settings Framework aims to take the pain out of creating settings pages for your WordPress plugins by effectively creating a wrapper around the WordPress settings API and making it super simple to create and maintain settings pages.
		 *
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/wp-settings-framework.php';
		
		
				
		/**
		 * Custom Post Type: Event_Registration_Pro_Event_CPT  
		 *
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-event-registration-pro-erp_event-cpt.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-event-registration-pro-erp_event-cpt-manager.php';
			

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-event-registration-pro-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-event-registration-pro-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the Dashboard.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-event-registration-pro-admin.php';
		
		
  		
		/**
		 * The class responsible for show all metaboxes
		 */
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-show-metabox.php';
		
		/**
		 * The class responsible for defining all metaboxe to add event fields
		 */
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-metabox.php';
		
		/**
		 * The class responsible for dashboard page
		 */
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-dashboard.php';
		
		/**
		 * The class responsible for event configuration page
		 */
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-configuration.php';
		
		/**
		 * The class responsible for event email templates page
		 */
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-email-templates.php';
		
		/**
		 * The class responsible for archive page
		 */
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-archive.php';
		
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-report-view.php';
		
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-report-add.php';
		
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-cron-mail.php';
		
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-event-registration-pro-individual-mail-send.php';
		
		require_once plugin_dir_path(dirname( __FILE__ )) . 'includes/class-add-ons-manager.php';
		
		
		  
		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-event-registration-pro-public.php';		
		$this->loader = new Event_Registration_Pro_Loader();
		
				

	}

	
	private function set_locale() {

		$plugin_i18n = new Event_Registration_Pro_i18n();
		$plugin_i18n->set_domain( $this->get_plugin_name() );

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	
	private function define_admin_hooks() {

		$plugin_admin = new Event_Registration_Pro_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );  
		
		//Datepicker js and css
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'erp_calendar_scripts' ); 
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Event_Registration_Pro_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );  
	} 
	
	/**
	 *  Remove Menus from left at admin
	**/
	private function remove_left_menus() { 
	 
		$plugin_register = new Event_Registration_Pro_Event_CPT();
		
		//Custom menu order
		$this->loader->add_filter('custom_menu_order', $plugin_register, 'order_index_catalog_menu_page', 'asc');
		
		//Remove add new menu from left
		$this->loader->add_action('admin_menu', $plugin_register, 'as_remove_menus'); 
		
		//Add enctype to event post form
		$this->loader->add_action('post_edit_form_tag', $plugin_register, 'add_post_enctype');  
		  
		if(isset($_GET['post_type'])){
			$typenow = trim(strip_tags(sanitize_text_field($_GET['post_type']))); 
			   
			//Add post columns
			$this->loader->add_filter('manage_edit-'.$typenow.'_columns', $plugin_register, 'custom_posts_columns_header');
			
			//Add post columns content
			$this->loader->add_action('manage_'.$typenow.'_posts_custom_column', $plugin_register, 'custom_posts_columns_body');
			
			//Add sortable columns
			$this->loader->add_filter('manage_edit-'.$typenow.'_sortable_columns', $plugin_register, 'custom_posts_sortable_columns');  
			$this->loader->add_filter('posts_orderby', $plugin_register, 'custom_sortable_posts_orderby');   
		} 
		
		if(isset($_GET['taxonomy']) && sanitize_text_field($_GET['taxonomy'])=='erp-event-category'){
			$this->loader->add_filter('manage_edit-erp-event-category_columns', $plugin_register, 'erp_event_taxonomy_columns');    
			$this->loader->add_filter('manage_erp-event-category_custom_column', $plugin_register, 'erp_event_taxonomy_column', 10, 3);    
		}
	}
	
	/**
	 *	Add metaboxes
	**/
	private function define_metaboxes() {  
		
		$plugin_metaboxes = new Event_Registration_Pro_Metabox();
		 
		//Dashboard
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_dashboard_page',1);  
		
		//Configuration
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_configuration_page',1);  
	
		//Add Event Details metabox
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_event_details_metabox',1);  
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_event_access_metabox',2);  
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_event_registration_metabox',3);   
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_event_emails_metabox',4);   
		//$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_event_repeating_metabox',5);   
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_event_metadata_metabox',6);   
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_event_tickets_metabox',7);   
		//$this->loader->add_action('admin_head', $plugin_metaboxes, 'replace_featured_image_box',8); 
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_excerpt_meta_box',9);  
		$this->loader->add_action('edit_form_after_title', $plugin_metaboxes, 'fn_move_deck',9);  
		$this->loader->add_filter('bulk_actions-edit-erp_event', $plugin_metaboxes, 'register_event_archive_bulk_action',10);  
		$this->loader->add_filter('handle_bulk_actions-edit-erp_event', $plugin_metaboxes, 'event_archive_bulk_action_handler',10,3);  
		$this->loader->add_action('admin_notices', $plugin_metaboxes, 'event_archive_bulk_action_admin_notice',10);  
		//$this->loader->add_action('admin_footer-post.php', $plugin_metaboxes, 'jc_append_post_status_list',10);   
		
		//................... 2 ..................
		
		//Add Location Manager metabox   
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_location_manager_metabox',1); 
		
		//................... 3 ..................
		
		//Add Organizers metabox
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_organizers_metabox',1);   
		 
		//Save custom fields data
		$this->loader->add_action('save_post', $plugin_metaboxes, 'save_custom_meta');    
		 
		//Save post order
		$this->loader->add_action('admin_init', $plugin_metaboxes, 'fn_saveorder'); 
		 
		//................... 4 ..................
		
		//Add Event Category metabox 
		$this->loader->add_action('erp-event-category_add_form_fields', $plugin_metaboxes, 'add_erp_extra_category_fields',1);    
		$this->loader->add_action('erp-event-category_edit_form_fields', $plugin_metaboxes, 'add_erp_extra_category_fields',1);    
		  
		//Save Categories Metabox
		$this->loader->add_action('edit_term', $plugin_metaboxes, 'save_erp_event_categories_metabox');  
		$this->loader->add_action('create_term', $plugin_metaboxes, 'save_erp_event_categories_metabox');  
		
		//................... 5 ..................
		
		//Show Registration Forms tags
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_regform_html_metabox',1);  
		
		//Show Registration Forms Fields
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_erp_regform_fields_metabox',2);  
		
		//Edit field values
		$this->loader->add_action('admin_init', $plugin_metaboxes, 'fn_get_regform_values', 3);
		
		//Delete 
		$this->loader->add_action('admin_init', $plugin_metaboxes, 'fn_deleteRegFormFields', 4); 
		
		//Save Registration Form fields sort order
		$this->loader->add_action('admin_init', $plugin_metaboxes, 'fn_save_regFormFields_order', 5); 
		
		//...................Email Templates...................
		$plugin_email_templates = new Event_Registration_Pro_EmailTemplates();
		$this->loader->add_action('admin_menu', $plugin_email_templates, 'add_event_email_templates_metaboxes',1);   
		
		//...................Archive Manager...................
		$this->loader->add_action('admin_menu', $plugin_metaboxes, 'add_archive_page',1);  
 	} 
	
	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Event_Registration_Pro_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	} 
	
	
}